@@ -5,6 +5,7 @@ from timeit import default_timer as timer
 from . import ml_model as ml_model
 import numpy as np
 from uuid import uuid4
+from . import yolo3_utils
 from . import yolo3_architecture as yolo3_architecture
 # from keras.utils import multi_gpu_model
 import tensorflow.compat.v1 as tf
@@ -31,8 +32,8 @@ tf.disable_eager_execution()
 
 
 class YOLO(ml_model.MLModel):
-    def __init__(self, model_name, config, model_date=None, **kwargs):
-        super().__init__(model_name, config, model_date)
+    def __init__(self, model_name, model_id=None, config_version='current_model', do_not_update=False):
+        super().__init__(model_name, model_id, config_version, do_not_update)
 
     def _get_objects_from_s3(self, dest_dir):
         s3_client = self._get_s3_client()
